@@ -1,5 +1,4 @@
 test_that("crew_controller_lsf() script() nearly empty", {
-  skip_if_low_dep_versions()
   x <- crew_controller_lsf(
     lsf_cwd = "/home"
   )
@@ -14,7 +13,6 @@ test_that("crew_controller_lsf() script() nearly empty", {
 })
 
 test_that("crew_controller_lsf() script() all lines", {
-  skip_if_low_dep_versions()
   x <- crew_controller_lsf(
     script_lines = c("module load R", "echo 'start'"),
     lsf_cwd = "/home",
@@ -39,3 +37,10 @@ test_that("crew_controller_lsf() script() all lines", {
   )
   expect_equal(out, exp)
 })
+
+test_that("deprecate seconds_exit", {
+  expect_warning(
+    x <- crew_controller_lsf(seconds_exit = 1),
+    class = "crew_deprecate"
+  )
+})
